cattr.experimental package
==========================

Submodules
----------

cattr.experimental.gen module
-----------------------------

.. automodule:: cattr.experimental.gen
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cattr.experimental
    :members:
    :undoc-members:
    :show-inheritance:
